@@ -30,6 +30,7 @@ import re
 
 
 pattern = re.compile(r"""(?P<propertyName>(?=^)\w[\s\w,]+)(?(1):)(?:\s|\n)?(?P<propertyData>[\W\w\s]+)""", re.MULTILINE)
+f_pattern = re.compile(r"""(?P<propertyName>(?=^)\w[\s\w,]+)(?(1):)""", re.MULTILINE)
 
 logHandler = handlers.RotatingFileHandler('tfs.log', maxBytes=20 * 1024 * 1024, backupCount=10)
 logging.basicConfig(
@@ -373,7 +374,22 @@ def get_last_branch_changeSet(branch, numberOfChangets):
         changeSetDict['branch'] = 'branch'
         changeSetDict['items'] = itemsDict
 
-        changeset_info_items = changeset_raw.split(endline_char * 2)
+        changeset_info_items = list()
+
+        propertyNames = f_pattern.findall(changeset_raw)
+        for item in propertyNames:
+            cur_idx = propertyNames.index(item)
+            next_idx = propertyNames.index(item) + 1
+            if next_idx <= len(propertyNames) - 1:
+                itm = changeset_raw[
+                      changeset_raw.find(propertyNames[cur_idx])
+                      :changeset_raw.find(propertyNames[next_idx])]
+            else:
+                itm = changeset_raw[
+                      changeset_raw.find(propertyNames[cur_idx]):]
+            changeset_info_items.append(itm)
+
+        # changeset_info_items = changeset_raw.split(endline_char + endline_char)
         changeset_items = list()
 
         for changeset_info_item in changeset_info_items:
@@ -407,12 +423,18 @@ def get_last_branch_changeSet(branch, numberOfChangets):
                             actions = action.split(', ')
                             if all(s in actions for s in ('delete', 'source rename')):
                                 action = 'delete'
+                            if all(s in actions for s in ('delete', 'rollback')):
+                                action = 'delete'
                             elif all(s in actions for s in ('encoding', 'edit')):
                                 action = 'edit'
                             elif all(s in actions for s in ('merge', 'edit')):
                                 action = 'edit'
+                            elif all(s in actions for s in ('edit', 'rollback')):
+                                action = 'edit'
                             elif all(s in actions for s in ('rename', 'edit')):
                                 action = 'rename'
+                            elif all(s in actions for s in ('add', 'source rename')):
+                                action = 'add'
 
                         if action not in itemsDict:
                             itemsDict[action] = [filename, ]
